# Changelog

## [2.2.1a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/2.2.1a1) (2024-11-07)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/2.2.0...2.2.1a1)

**Merged pull requests:**

- pt-pt/translate [\#271](https://github.com/OpenVoiceOS/OVOS-workshop/pull/271) ([gitlocalize-app[bot]](https://github.com/apps/gitlocalize-app))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
